package com.ruoyi.ss.menu.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.ss.menu.domain.EtMenu;
import com.ruoyi.ss.menu.mapper.EtMenuMapper;
import com.ruoyi.ss.menu.service.IEtMenuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 前端菜单Service业务层处理
 *
 * @author ruoyi
 * @date 2024-12-07
 */
@Service
public class EtMenuServiceImpl implements IEtMenuService
{
    @Autowired
    private EtMenuMapper etMenuMapper;

    /**
     * 查询前端菜单
     *
     * @param menuId 前端菜单主键
     * @return 前端菜单
     */
    @Override
    public EtMenu selectEtMenuByMenuId(Long menuId)
    {
        return etMenuMapper.selectEtMenuByMenuId(menuId);
    }

    /**
     * 查询前端菜单列表
     *
     * @param etMenu 前端菜单
     * @return 前端菜单
     */
    @Override
    public List<EtMenu> selectEtMenuList(EtMenu etMenu)
    {
        return etMenuMapper.selectEtMenuList(etMenu);
    }

    /**
     * 根据用户角色查询所有菜单
     *
     * @param role 角色
     * @return 前端菜单
     */
    @Override
    public List<EtMenu> selectEtMenuListByRole(String role) {
        return etMenuMapper.selectEtMenuListByRole(role);
    }

    /**
     * 新增前端菜单
     *
     * @param etMenu 前端菜单
     * @return 结果
     */
    @Override
    public int insertEtMenu(EtMenu etMenu)
    {
        etMenu.setCreateTime(DateUtils.getNowDate());
        return etMenuMapper.insertEtMenu(etMenu);
    }

    /**
     * 修改前端菜单
     *
     * @param etMenu 前端菜单
     * @return 结果
     */
    @Override
    public int updateEtMenu(EtMenu etMenu)
    {
        return etMenuMapper.updateEtMenu(etMenu);
    }

    /**
     * 批量删除前端菜单
     *
     * @param menuIds 需要删除的前端菜单主键
     * @return 结果
     */
    @Override
    public int deleteEtMenuByMenuIds(Long[] menuIds)
    {
        return etMenuMapper.deleteEtMenuByMenuIds(menuIds);
    }

    /**
     * 删除前端菜单信息
     *
     * @param menuId 前端菜单主键
     * @return 结果
     */
    @Override
    public int deleteEtMenuByMenuId(Long menuId)
    {
        return etMenuMapper.deleteEtMenuByMenuId(menuId);
    }
}
